@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 1998 Steve Borho <borho@stlnet.com>
+** Copyright (C) 1998 Steve Borho <steve@borho.myip.org>
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -508,7 +508,7 @@ void            printHelp(int argc, char *argv[])
 {
     fprintf(stderr, "mount.app %s - the WindowMaker universal mount point\n",
             VERSION);
-    fprintf(stderr, "Copyright (C) 1999  Steve Borho <borho@stlnet.com>\n");
+    fprintf(stderr, "Copyright (C) 1999  Steve Borho <steve@borho.myip.org>\n");
     fprintf(stderr, "This software comes with ABSOLUTELY NO WARRANTY\n");
     fprintf(stderr, "This software is free software, and you are welcome "
         "to redistribute it\n");
@@ -588,9 +588,9 @@ void            checkMount(allInfo * ai, bool forced)
              * data.  Maybe we should color code bad mount points in
              * the future.
              */
-            mp->totalSize = (long)100;
-            mp->availSize = (long)0;
-            mp->freeSize = (long)0;
+            mp->totalSize = (double)100;
+            mp->availSize = (double)0;
+            mp->freeSize = (double)0;
             mp->currentCap = 0;
             update(ai);
             return;
@@ -622,9 +622,9 @@ void            checkMount(allInfo * ai, bool forced)
             (sfs.f_blocks - sfs.f_bfree + sfs.f_bavail) + .5);
 
         /* Save these statistics for later when showing capacity */
-        mp->totalSize = (long)(sfs.f_blocks) * (sfs.f_bsize);
-        mp->availSize = (long)(sfs.f_bavail) * (sfs.f_bsize);
-        mp->freeSize = (long)(sfs.f_bfree) * (sfs.f_bsize);
+        mp->totalSize = (double)(sfs.f_blocks) * (sfs.f_bsize);
+        mp->availSize = (double)(sfs.f_bavail) * (sfs.f_bsize);
+        mp->freeSize = (double)(sfs.f_bfree) * (sfs.f_bsize);
     }
 
     if (nowMounted)
@@ -779,7 +779,7 @@ void            repaint()
 
 /* Helper function for update()
  * Turns a size (in byte) into something human-readable */
-void		format_size(char *s, unsigned long size_in_byte)
+void		format_size(char *s, double size_in_byte)
 {
    const char *unit;
    double size = (double) size_in_byte;
